import { InterfaceVpcEndpoint } from '@aws-cdk/aws-ec2';
import { Grant, IGrantable } from '@aws-cdk/aws-iam';
import { Construct, IConstruct } from '@aws-cdk/core';
export interface RepositoryProps {
    /**
     * The description of the Repository resource.
     */
    readonly description?: string;
    /**
     * The name of the Domain.
     *
     * @default - a name is generated by CDK.
     */
    readonly domainName?: string;
    /**
     * The name of the Repository.
     *
     * @default domainName
     */
    readonly repositoryName?: string;
}
export interface IRepository extends IConstruct {
    /** The ARN of the CodeArtifact Domain that contains the repository. */
    readonly repositoryDomainArn: string;
    /** The effective name of the CodeArtifact Domain. */
    readonly repositoryDomainName: string;
    /** The owner account of the CodeArtifact Domain. */
    readonly repositoryDomainOwner: string;
    /** The ARN of the CodeArtifact Repository. */
    readonly repositoryArn: string;
    /** The effective name of the CodeArtifact Repository. */
    readonly repositoryName: string;
    /** The URL to the endpoint of the CodeArtifact Repository for use with NPM. */
    readonly repositoryNpmEndpoint: string;
    /**
     * Grants read-only access to the repository, for use with NPM.
     *
     * @param grantee the entity to be granted read access.
     *
     * @returns the resulting `Grant`.
     */
    grantReadFromRepository(grantee: IGrantable): Grant;
}
/**
 * A CodeArtifact repository with an npmjs.com upstream connection.
 */
export declare class Repository extends Construct implements IRepository {
    #private;
    /**
     * The ARN of the CodeArtifact Domain that contains the repository.
     */
    readonly repositoryDomainArn: string;
    /**
     * The name of the CodeArtifact Domain that contains the repository.
     */
    readonly repositoryDomainName: string;
    /**
     * The account ID that owns the CodeArtifact Domain that contains the repository.
     */
    readonly repositoryDomainOwner: string;
    /**
     * The ARN of the CodeArtifact Repository.
     */
    readonly repositoryArn: string;
    /**
     * The name of the CodeArtifact Repository.
     */
    readonly repositoryName: string;
    constructor(scope: Construct, id: string, props?: RepositoryProps);
    /**
     * The npm repository endpoint to use for interacting with this repository.
     */
    get repositoryNpmEndpoint(): string;
    /**
     * The S3 bucket in which CodeArtifact stores the package data. When using
     * VPC Endpoints for CodeArtifact, an S3 Gateway Endpoint must also be
     * available, which allows reading from this bucket.
     */
    get s3BucketArn(): string;
    grantReadFromRepository(grantee: IGrantable): Grant;
    /**
     * Obtains a view of this repository that is intended to be accessed though
     * VPC endpoints.
     *
     * @param api          an `InterfaceVpcEndpoint` to the `codeartifact.api`
     *                     service.
     * @param repositories an `InterfaceVpcEndpoint` to the
     *                    `codeartifact.repositories` service.
     *
     * @returns a view of this repository that appropriately grants permissions on
     *          the VPC endpoint policies, too.
     */
    throughVpcEndpoint(api: InterfaceVpcEndpoint, repositories: InterfaceVpcEndpoint): IRepository;
}
